==> jc-1.4.0.tar.gz: polyglot/frontend/VisitorPass.h <==
// public class polyglot.frontend.VisitorPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 7b9f5dfde8305cae polyglot_frontend_VisitorPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_VisitorPass_H_
#define _JC_polyglot_frontend_VisitorPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_frontend_VisitorPass$sub_refs	_jc_polyglot_frontend_VisitorPass$sub_refs;
typedef struct _jc_polyglot_frontend_VisitorPass$sub_nonrefs	_jc_polyglot_frontend_VisitorPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_VisitorPass$refs	_jc_polyglot_frontend_VisitorPass$refs;
typedef struct _jc_polyglot_frontend_VisitorPass$nonrefs	_jc_polyglot_frontend_VisitorPass$nonrefs;
typedef struct _jc_polyglot_frontend_VisitorPass$object	_jc_polyglot_frontend_VisitorPass$object;

typedef const struct _jc_polyglot_frontend_VisitorPass$vmethods	_jc_polyglot_frontend_VisitorPass$vmethods;
typedef const struct _jc_polyglot_frontend_VisitorPass$vtable	_jc_polyglot_frontend_VisitorPass$vtable;
typedef const struct _jc_polyglot_frontend_VisitorPass$vtype	_jc_polyglot_frontend_VisitorPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_VisitorPass$method$_init$21bc67ff6e7809cf(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *);
extern void _jc_polyglot_frontend_VisitorPass$method$_init$75012b158bf4460c(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_VisitorPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_VisitorPass$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *);
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_frontend_VisitorPass$method$visitor$d73b4a2f60de4b0a(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *);
extern void _jc_polyglot_frontend_VisitorPass$method$visitor$ef87472ed55f55eb(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_visit_NodeVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$run$1ec62afce18bd5ee;
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$visitor$d73b4a2f60de4b0a;
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$visitor$ef87472ed55f55eb;

// Virtual methods structure
struct _jc_polyglot_frontend_VisitorPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *);
	struct _jc_polyglot_visit_NodeVisitor$object	*(*visitor$d73b4a2f60de4b0a)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *);
	void	(*visitor$ef87472ed55f55eb)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_visit_NodeVisitor$object *);
};

// Vtable
struct _jc_polyglot_frontend_VisitorPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_VisitorPass$vmethods	polyglot_frontend_VisitorPass;
};

// Vtype
struct _jc_polyglot_frontend_VisitorPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_VisitorPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_VisitorPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_visit_NodeVisitor$object	*v;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_VisitorPass$refs {
    _jc_polyglot_frontend_VisitorPass$sub_refs	polyglot_frontend_VisitorPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_VisitorPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_VisitorPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_VisitorPass$sub_nonrefs	polyglot_frontend_VisitorPass;
};

// Object instance structure
struct _jc_polyglot_frontend_VisitorPass$object {
	_jc_polyglot_frontend_VisitorPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_VisitorPass$vtype	*vtype;
	_jc_polyglot_frontend_VisitorPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_VisitorPass$vtype _jc_polyglot_frontend_VisitorPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_VisitorPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_VisitorPass$class_object;

#endif	/* _JC_polyglot_frontend_VisitorPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/VisitorPass.h <==
// public class polyglot.frontend.VisitorPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class 7b9f5dfde8305cae polyglot_frontend_VisitorPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_VisitorPass_H_
#define _JC_polyglot_frontend_VisitorPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;
struct _jc_polyglot_visit_NodeVisitor$object;

// Typedefs
typedef struct _jc_polyglot_frontend_VisitorPass$sub_refs	_jc_polyglot_frontend_VisitorPass$sub_refs;
typedef struct _jc_polyglot_frontend_VisitorPass$sub_nonrefs	_jc_polyglot_frontend_VisitorPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_VisitorPass$refs	_jc_polyglot_frontend_VisitorPass$refs;
typedef struct _jc_polyglot_frontend_VisitorPass$nonrefs	_jc_polyglot_frontend_VisitorPass$nonrefs;
typedef struct _jc_polyglot_frontend_VisitorPass$object	_jc_polyglot_frontend_VisitorPass$object;

typedef const struct _jc_polyglot_frontend_VisitorPass$vmethods	_jc_polyglot_frontend_VisitorPass$vmethods;
typedef const struct _jc_polyglot_frontend_VisitorPass$vtable	_jc_polyglot_frontend_VisitorPass$vtable;
typedef const struct _jc_polyglot_frontend_VisitorPass$vtype	_jc_polyglot_frontend_VisitorPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_VisitorPass$method$_init$21bc67ff6e7809cf(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_frontend_VisitorPass$method$_init$75012b158bf4460c(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_VisitorPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_VisitorPass$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_visit_NodeVisitor$object *_jc_polyglot_frontend_VisitorPass$method$visitor$d73b4a2f60de4b0a(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_frontend_VisitorPass$method$visitor$ef87472ed55f55eb(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$run$1ec62afce18bd5ee;
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$visitor$d73b4a2f60de4b0a;
extern _jc_method _jc_polyglot_frontend_VisitorPass$method_info$visitor$ef87472ed55f55eb;

// Virtual methods structure
struct _jc_polyglot_frontend_VisitorPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_visit_NodeVisitor$object	*(*visitor$d73b4a2f60de4b0a)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *) _JC_JCNI_ATTR;
	void	(*visitor$ef87472ed55f55eb)(_jc_env *, struct _jc_polyglot_frontend_VisitorPass$object *, struct _jc_polyglot_visit_NodeVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_VisitorPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_VisitorPass$vmethods	polyglot_frontend_VisitorPass;
};

// Vtype
struct _jc_polyglot_frontend_VisitorPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_VisitorPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_VisitorPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
	struct _jc_polyglot_visit_NodeVisitor$object	*v;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_VisitorPass$refs {
    _jc_polyglot_frontend_VisitorPass$sub_refs	polyglot_frontend_VisitorPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_VisitorPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_VisitorPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_VisitorPass$sub_nonrefs	polyglot_frontend_VisitorPass;
};

// Object instance structure
struct _jc_polyglot_frontend_VisitorPass$object {
	_jc_polyglot_frontend_VisitorPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_VisitorPass$vtype	*vtype;
	_jc_polyglot_frontend_VisitorPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_VisitorPass$vtype _jc_polyglot_frontend_VisitorPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_VisitorPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_VisitorPass$class_object;

#endif	/* _JC_polyglot_frontend_VisitorPass_H_ */
